<?php

namespace Drupal\micro_site\Entity;

use Drupal\Core\Entity\RevisionLogInterface;
use Drupal\Core\Entity\RevisionableInterface;
use Drupal\Core\Entity\EntityChangedInterface;
use Drupal\Core\Entity\EntityPublishedInterface;
use Drupal\file\FileInterface;
use Drupal\user\EntityOwnerInterface;
use Drupal\micro_site\SiteUsers;

/**
 * Provides an interface for defining Site entities.
 *
 * @ingroup micro_site
 */
interface SiteInterface extends RevisionableInterface, RevisionLogInterface, EntityChangedInterface, EntityOwnerInterface, EntityPublishedInterface {

  // Add get/set methods for your configuration properties here.

  /**
   * Gets the Site name.
   *
   * @return string
   *   Name of the Site.
   */
  public function getName();

  /**
   * Sets the Site name.
   *
   * @param string $name
   *   The Site name.
   *
   * @return \Drupal\micro_site\Entity\SiteInterface
   *   The called Site entity.
   */
  public function setName($name);

  /**
   * Gets the Site mail.
   *
   * @return string
   *   Email of the Site.
   */
  public function getEmail();

  /**
   * Sets the Site mail.
   *
   * @param string $mail
   *   The Site mail.
   *
   * @return \Drupal\micro_site\Entity\SiteInterface
   *   The called Site entity.
   */
  public function setEmail($mail);

  /**
   * Gets the Site slogan.
   *
   * @return string
   *   Slogan of the Site.
   */
  public function getSlogan();

  /**
   * Sets the Site slogan.
   *
   * @param string $slogan
   *   The Site slogan.
   *
   * @return \Drupal\micro_site\Entity\SiteInterface
   *   The called Site entity.
   */
  public function setSlogan($slogan);

  /**
   * Gets the Site logo.
   *
   * @return \Drupal\file\FileInterface
   *  The file entity.
   */
  public function getLogo();

  /**
   * Sets the Site logo.
   *
   * @param \Drupal\file\FileInterface $logo
   *   The logo file entity.
   *
   * @return \Drupal\micro_site\Entity\SiteInterface
   *   The called Site entity.
   */
  public function setLogo(FileInterface $logo);

  /**
   * Gets the Site creation timestamp.
   *
   * @return int
   *   Creation timestamp of the Site.
   */
  public function getCreatedTime();

  /**
   * Sets the Site creation timestamp.
   *
   * @param int $timestamp
   *   The Site creation timestamp.
   *
   * @return \Drupal\micro_site\Entity\SiteInterface
   *   The called Site entity.
   */
  public function setCreatedTime($timestamp);

  /**
   * Returns the Site registered status indicator.
   *
   * Registered Site are only visible to restricted users. This status is
   * mandatory to be able to manage content, users, menu on the site. A site
   * registered is always accessible from its site URL.
   *
   * @return bool
   *   TRUE if the Site is registered.
   */
  public function isRegistered();

  /**
   * Sets the registered status of a Site.
   *
   * @param bool|null $registered
   *   TRUE to set this Site to registered, FALSE to set it to unregistered.
   *
   * @return \Drupal\micro_site\Entity\SiteInterface
   *   The called Site entity.
   */
  public function setRegistered($registered = NULL);

  /**
   * Returns the Site published status indicator.
   *
   * Unpublished Site are only visible to restricted users.
   *
   * @return bool
   *   TRUE if the Site is published.
   */
  public function isPublished();

  /**
   * Sets the published status of a Site.
   *
   * @param bool|null $published
   *   TRUE to set this Site to published, FALSE to set it to unpublished.
   *
   * @return \Drupal\micro_site\Entity\SiteInterface
   *   The called Site entity.
   */
  public function setPublished($published = NULL);

  /**
   * Gets the Site revision creation timestamp.
   *
   * @return int
   *   The UNIX timestamp of when this revision was created.
   */
  public function getRevisionCreationTime();

  /**
   * Sets the Site revision creation timestamp.
   *
   * @param int $timestamp
   *   The UNIX timestamp of when this revision was created.
   *
   * @return \Drupal\micro_site\Entity\SiteInterface
   *   The called Site entity.
   */
  public function setRevisionCreationTime($timestamp);

  /**
   * Gets the Site revision author.
   *
   * @return \Drupal\user\UserInterface
   *   The user entity for the revision author.
   */
  public function getRevisionUser();

  /**
   * Sets the Site revision author.
   *
   * @param int $uid
   *   The user ID of the revision author.
   *
   * @return \Drupal\micro_site\Entity\SiteInterface
   *   The called Site entity.
   */
  public function setRevisionUserId($uid);

  /**
   * Gets the host url for sites entities set in the configuration module.
   *
   * @return string
   *   A URL string for the host base path to the site. (e.g. example.com)
   */
  public static function getHostBaseUrl();

  /**
   * Gets the path for a site.
   *
   * @return string
   *   A URL string for the base path to the site. (e.g. http://example.com/)
   */
  public function getSitePath();

  /**
   * Gets the url type for a site.
   *
   * @return string
   *   A strind subdomain|domain
   */
  public function getTypeUrl();

  /**
 * Gets the url for a site.
 *
 * @return string
 *   A URL string for the base url to the site. (e.g. example.com/)
 */
  public function getSiteUrl();

  /**
   * Is the site must have a menu associated.
   *
   * @return boolean
   *   TRUE if the site must have a menu.
   */
  public function hasMenu();

  /**
   * Get the menu machine name associated with the site.
   *
   * @return string
   *   The menu machine name.
   */
  public function getSiteMenu();

  /**
   * Set the menu machine name associated with the site.
   *
   * @param string $site_menu
   *   The menu machine name.
   *
   * @return |Drupal\micro_site\Entity\SiteInterface
   *   The site entity.
   */
  public function setSiteMenu($site_menu);

  /**
   * Gets the scheme for a site.
   *
   * @return string
   *   A URL string for the scheme site. (e.g. http oir https)
   */
  public function getSiteScheme();

  /**
   * The Shield site is enabled.
   *
   * @return boolean
   *   TRUE if shield is enabled.
   */
  public function getSiteShield();

  /**
   * Gets the shield user.
   *
   * @return string
   *   The user shield.
   */
  public function getSiteShieldUser();

  /**
   * Gets the shield user's password.
   *
   * @return string
   *   The user's password shield.
   */
  public function getSiteShieldPassword();

  /**
   * Get the site users entities for a given field_name.
   *
   * @param string $field_name
   *   The field name which reference site users.
   *
   * @return \Drupal\user\UserInterface[]
   *   The users entities.
   */
  public function getUsers($field_name = SiteUsers::MICRO_SITE_ADMINISTRATOR);


  /**
 * Get the site users id for a given field_name.
 *
 * @param string $field_name
 *   The field name which reference site users.
 * @param boolean $return_entity
 *   If TRUE, return an array of user entity.
 *
 * @return array|\Drupal\user\UserInterface[]
 *   An array of the users id or users entity.
 */
  public function getUsersId($field_name = SiteUsers::MICRO_SITE_ADMINISTRATOR, $return_entity = FALSE);

  /**
   * Get all the site users id.
   *
   * @param boolean $return_entity
   *   If TRUE, return an array of user entity.
   *
   * @return array|\Drupal\user\UserInterface[]
   *   An array of the users id or users entity.
   *
   */
  public function getAllUsersId($return_entity = FALSE);

  /**
   * Get the site administrator users id.
   *
   * @param boolean $return_entity
   *   If TRUE, return an array of user entity.
   *
   * @return array|\Drupal\user\UserInterface[]
   *   An array of the users id or users entity.
   *
   */
  public function getAdminUsersId($return_entity = FALSE);

  /**
   * Get the site manager users id.
   *
   * @param boolean $return_entity
   *   If TRUE, return an array of user entity.
   *
   * @return array|\Drupal\user\UserInterface[]
   *   An array of the users id or users entity.
   *
   */
  public function getManagerUsersId($return_entity = FALSE);

  /**
   * Get the site contributor users id.
   *
   * @param boolean $return_entity
   *   If TRUE, return an array of user entity.
   *
   * @return array|\Drupal\user\UserInterface[]
   *   An array of the users id or users entity.
   *
   */
  public function getContributorUsersId($return_entity = FALSE);

}
